@@ -7,9 +7,11 @@ from gi.repository import Totem
 class SamplePython(gobject.GObject, Peas.Activatable):
 	__gtype_name__ = 'SamplePython'
 
-	def do_activate(self, totem):
+	object = gobject.property(type = gobject.GObject)
+
+	def do_activate(self):
 		print "Activating sample Python plugin"
-		totem.action_fullscreen_toggle()
+		self.object.action_fullscreen_toggle()
 	
-	def do_deactivate(self, totem):
+	def do_deactivate(self):
 		print "Deactivating sample Python plugin"
