@@ -43,11 +43,9 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
-#include <gconf/gconf-client.h>
+#include <gtk/gtkx.h>
 
 #include "totem-interface.h"
-#include "totem-private.h"
 
 static GtkWidget *
 totem_interface_error_dialog (const char *title, const char *reason,
@@ -129,14 +127,13 @@ totem_interface_error_blocking (const char *title, const char *reason,
  * @uri: the URI to open
  * @label: a label for the URI's button, or %NULL to use @uri as the label
  * @parent: the error dialogue's parent #GtkWindow
- * @totem: a #TotemObject
  *
  * Display a modal error dialogue like totem_interface_error(),
  * but add a button which will open @uri in a browser window.
  **/
 void
 totem_interface_error_with_link (const char *title, const char *reason,
-				 const char *uri, const char *label, GtkWindow *parent, Totem *totem)
+				 const char *uri, const char *label, GtkWindow *parent)
 {
 	GtkWidget *error_dialog, *link_button, *hbox;
 
@@ -159,6 +156,17 @@ totem_interface_error_with_link (const char *title, const char *reason,
 	gtk_window_present (GTK_WINDOW (error_dialog));
 }
 
+/**
+ * totem_interface_load:
+ * @name: the #GtkBuilder UI file to load
+ * @fatal: %TRUE if errors loading the file should be fatal, %FALSE otherwise
+ * @parent: (allow-none): the parent window to use when displaying error dialogues, or %NULL
+ * @user_data: (allow-none): the user data to pass to gtk_builder_connect_signals(), or %NULL
+ *
+ * Load a #GtkBuilder UI file with the given name and return the #GtkBuilder instance for it. If loading the file fails, an error dialogue is shown.
+ *
+ * Return value: (transfer full): the loaded #GtkBuilder object, or %NULL
+ */
 GtkBuilder *
 totem_interface_load (const char *name, gboolean fatal, GtkWindow *parent, gpointer user_data)
 {
@@ -186,6 +194,17 @@ totem_interface_load (const char *name, gboolean fatal, GtkWindow *parent, gpoin
 	return builder;
 }
 
+/**
+ * totem_interface_load_with_full_path:
+ * @filename: the #GtkBuilder UI file path to load
+ * @fatal: %TRUE if errors loading the file should be fatal, %FALSE otherwise
+ * @parent: (allow-none): the parent window to use when displaying error dialogues, or %NULL
+ * @user_data: (allow-none): the user data to pass to gtk_builder_connect_signals(), or %NULL
+ *
+ * Load a #GtkBuilder UI file from the given path and return the #GtkBuilder instance for it. If loading the file fails, an error dialogue is shown.
+ *
+ * Return value: (transfer full): the loaded #GtkBuilder object, or %NULL
+ */
 GtkBuilder *
 totem_interface_load_with_full_path (const char *filename, gboolean fatal, 
 				     GtkWindow *parent, gpointer user_data)
@@ -218,6 +237,14 @@ totem_interface_load_with_full_path (const char *filename, gboolean fatal,
 	return builder;
 }
 
+/**
+ * totem_interface_load_pixbuf:
+ * @name: the image file name
+ *
+ * Load the image called @name in the directory given by totem_interface_get_full_path() into a #GdkPixbuf.
+ *
+ * Return value: (transfer full): the loaded pixbuf, or %NULL
+ */
 GdkPixbuf*
 totem_interface_load_pixbuf (const char *name)
 {
@@ -266,7 +293,7 @@ totem_gtk_plug_get_toplevel (GtkPlug *plug)
 {
 	Window root, parent, *children;
 	guint nchildren;
-	GdkNativeWindow xid;
+	Window xid;
 
 	g_return_val_if_fail (GTK_IS_PLUG (plug), NULL);
 
@@ -275,7 +302,7 @@ totem_gtk_plug_get_toplevel (GtkPlug *plug)
 	do
 	{
 		/* FIXME: multi-head */
-		if (XQueryTree (GDK_DISPLAY (), xid, &root,
+		if (XQueryTree (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xid, &root,
 					&parent, &children, &nchildren) == 0)
 		{
 			g_warning ("Couldn't find window manager window");
@@ -284,7 +311,7 @@ totem_gtk_plug_get_toplevel (GtkPlug *plug)
 
 		if (root == parent) {
 			GdkWindow *toplevel;
-			toplevel = gdk_window_foreign_new (xid);
+			toplevel = gdk_x11_window_foreign_new_for_display (gdk_display_get_default (), xid);
 			return toplevel;
 		}
 
